@@ -1,12 +1,13 @@
-import re
-import json
-import argparse
-import fileinput
-import jaconv
-
-from kuro2sudachi.normalizer import SudachiCharNormalizer
-from sudachipy import tokenizer
 from sudachipy import dictionary
+from sudachipy import tokenizer
+from kuro2sudachi.normalizer import SudachiCharNormalizer
+import jaconv
+import fileinput
+import argparse
+import json
+import os
+import re
+
 
 mode = tokenizer.Tokenizer.SplitMode.C
 
@@ -21,17 +22,17 @@ parser.add_argument(
 )
 parser.add_argument("-o", "--out", help="output path")
 parser.add_argument(
-    "-d", "--rewrite_def", help="rewrite text file path (default: ./rewrite.def)"
+    "-d",
+    "--rewrite_def",
+    default=os.path.dirname(os.path.abspath(__file__)) + "/rewrite.def",
+    help="rewrite text file path",
 )
 parser.add_argument(
     "-e", "--rm_already_exist", help="remove words system dict already exist"
 )
-parser.add_argument(
-    "-r", "--sudachi_setting", help="the setting file in JSON format"
-)
-parser.add_argument(
-    "-s", "--sudachi_dict_type", help="sudachidict type"
-)
+parser.add_argument("-r", "--sudachi_setting",
+                    help="the setting file in JSON format")
+parser.add_argument("-s", "--sudachi_dict_type", help="sudachidict type")
 parser.add_argument(
     "--ignore",
     action="store_true",
@@ -69,9 +70,20 @@ class DictFormatError(Error):
 
 
 class Converter:
-    def __init__(self, rewrite_file="rewrite.def", config=None, sudachi_setting=None, dict_type="core", rm=False):
+    def __init__(
+        self,
+        rewrite_file,
+        config=None,
+        sudachi_setting=None,
+        dict_type="core",
+        rm=False,
+    ):
+        if rewrite_file == "":
+            raise DictFormatError(f"rewrite.def file path is required")
+
         self.tokenizer = dictionary.Dictionary(
-            dict_type=dict_type, config_path=sudachi_setting).create()
+            dict_type=dict_type, config_path=sudachi_setting
+        ).create()
 
         if config is not None:
             with open(config) as f:
@@ -127,8 +139,13 @@ def cli() -> str:
     sudachi_setting = args.sudachi_setting
     sudachi_dict_type = args.sudachi_dict_type
 
-    c = Converter(rewrite, config, sudachi_setting=sudachi_setting,
-                  dict_type=sudachi_dict_type, rm=rm)
+    c = Converter(
+        rewrite,
+        config,
+        sudachi_setting=sudachi_setting,
+        dict_type=sudachi_dict_type,
+        rm=rm,
+    )
 
     with fileinput.input(files=args.file) as input:
         for line in input:
